<div class="fade-in">
    <div class="bg-clay-800 rounded-lg overflow-hidden">
        <div class="flex items-center justify-between px-4 py-2 bg-clay-700">
            <span class="text-clay-300 text-sm font-medium">{{ event_type }}</span>
            <button 
                onclick="navigator.clipboard.writeText(document.getElementById('webhook-json').textContent).then(() => this.textContent = 'Copied!')"
                class="px-3 py-1 bg-clay-600 text-clay-200 rounded text-xs hover:bg-clay-500 transition-colors"
            >
                Copy
            </button>
        </div>
        <pre class="p-4 overflow-x-auto"><code id="webhook-json" class="text-sm">{{ payload }}</code></pre>
    </div>
    
    <div class="mt-4 p-4 bg-sage-50 border border-sage-200 rounded-lg">
        <h4 class="font-medium text-sage-800 text-sm mb-2">Testing Tips:</h4>
        <ul class="text-sage-700 text-sm space-y-1">
            <li>1. Copy this payload and send it to your webhook endpoint</li>
            <li>2. Remember to include the <code class="bg-sage-100 px-1 rounded">X-Credo-Signature</code> header</li>
            <li>3. Signature = SHA512(webhook_token + business_code)</li>
        </ul>
    </div>
</div>
